# -*- coding: utf-8 -*-

"""
Automated Tool for Optimized Modelling (ATOM)
Author: Mavs
Description: Import API and declare version.

"""

from .api import ATOMClassifier, ATOMRegressor, ATOMLoader, ATOMModel

__version__ = "4.12.0"
